



pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
pytest -vv -ra --showlocals -m "not (isolated or network or virtualenv or setuptools or broken_on_urct)" --deselect=tests/test_editable_unit.py::test_navigate_editable_pkg --deselect=tests/test_file_processor.py::test_on_each_with_symlink --deselect=tests/test_pyproject_extra_dirs.py::test_pep517_wheel_extra_dirs --deselect=tests/test_pyproject_pep660.py::test_pep660_wheel -k "not (sdist_time_hash_set_epoch or sdist_hash)"
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
